@@ -3,12 +3,13 @@ from .edn_lex import Keyword, Symbol
 from .edn_parse import parse as loads
 from .edn_parse import add_tag, remove_tag, TaggedElement
 from .edn_dump import dump as dumps
-
+from .immutable_dict import ImmutableDict
 
 __all__ = ('loads',
            'dumps',
+           'ImmutableDict',
            'Keyword',
            'Symbol',
            'add_tag',
            'remove_tag',
-           'TaggedElement')
\ No newline at end of file
+           'TaggedElement')
